# pyDtwSat
This Package is adapted from Victor Maus's R package dtwSat.

Dynamic Time Warping and Time-Weighted Dynamic Time Warping (TWDTW) for satellite image time series analysis. pyDtwSat provides visulisation to land use land cover  classification of the time series of satellite images.



## References

<div id="refs" class="references csl-bib-body hanging-indent">

<div id="ref-Maus:2019" class="csl-entry">

Maus, Victor, Gilberto Camara, Marius Appel, and Edzer Pebesma. 2019.
“<span class="nocase">dtwSat</span>: Time-Weighted Dynamic Time Warping
for Satellite Image Time Series Analysis in R.” *Journal of Statistical
Software* 88 (5): 1–31. <https://doi.org/10.18637/jss.v088.i05>.

</div>

<div id="ref-Maus:2016" class="csl-entry">

Maus, Victor, Gilberto Camara, Ricardo Cartaxo, Alber Sanchez, Fernando
M. Ramos, and Gilberto R. de Queiroz. 2016. “A Time-Weighted Dynamic
Time Warping Method for Land-Use and Land-Cover Mapping.” *IEEE Journal
of Selected Topics in Applied Earth Observations and Remote Sensing* 9
(8): 3729–39. <https://doi.org/10.1109/JSTARS.2016.2517118>.

</div>

</div>